**Example 1: 请求示例**



Input: 

```
tccli live ModifyLivePlayAuthKey --cli-unfold-argument  \
    --DomainName 5000.livepush.myqcloud.com \
    --Enable 0 \
    --AuthKey xxxx \
    --AuthDelta 300 \
    --AuthBackKey xxxx
```

Output: 
```
{
    "Response": {
        "RequestId": "3c140219-cfe9-470e-b241-907877d6fb03"
    }
}
```

